# coding: utf-8

"""
    Swagger Blended Hub API Explorer

    A collection of Swagger documentation for the Blended Hub APIs.

    OpenAPI spec version: 1.0.0
    Contact: api@blended.co
    Generated by: https://github.com/swagger-api/swagger-codegen.git

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.
"""

from pprint import pformat
from six import iteritems
import re


class User(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self, href=None, pk=None, status=None, name=None, registered_date=None, user_name=None, slug=None, email=None, accounts=None, currentaccount=None, activationchallenge=None, verified=None, profile_picture=None, subscription=None):
        """
        User - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'href': 'str',
            'pk': 'int',
            'status': 'str',
            'name': 'str',
            'registered_date': 'datetime',
            'user_name': 'str',
            'slug': 'str',
            'email': 'str',
            'accounts': 'object',
            'currentaccount': 'object',
            'activationchallenge': 'object',
            'verified': 'bool',
            'profile_picture': 'str',
            'subscription': 'str'
        }

        self.attribute_map = {
            'href': 'href',
            'pk': 'pk',
            'status': 'status',
            'name': 'name',
            'registered_date': 'registered_date',
            'user_name': 'user_name',
            'slug': 'slug',
            'email': 'email',
            'accounts': 'accounts',
            'currentaccount': 'currentaccount',
            'activationchallenge': 'activationchallenge',
            'verified': 'verified',
            'profile_picture': 'profile_picture',
            'subscription': 'subscription'
        }

        self._href = href
        self._pk = pk
        self._status = status
        self._name = name
        self._registered_date = registered_date
        self._user_name = user_name
        self._slug = slug
        self._email = email
        self._accounts = accounts
        self._currentaccount = currentaccount
        self._activationchallenge = activationchallenge
        self._verified = verified
        self._profile_picture = profile_picture
        self._subscription = subscription

    @property
    def href(self):
        """
        Gets the href of this User.
        current object reference url

        :return: The href of this User.
        :rtype: str
        """
        return self._href

    @href.setter
    def href(self, href):
        """
        Sets the href of this User.
        current object reference url

        :param href: The href of this User.
        :type: str
        """

        self._href = href

    @property
    def pk(self):
        """
        Gets the pk of this User.
        unique id of user account.

        :return: The pk of this User.
        :rtype: int
        """
        return self._pk

    @pk.setter
    def pk(self, pk):
        """
        Sets the pk of this User.
        unique id of user account.

        :param pk: The pk of this User.
        :type: int
        """

        self._pk = pk

    @property
    def status(self):
        """
        Gets the status of this User.
        user account status.

        :return: The status of this User.
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """
        Sets the status of this User.
        user account status.

        :param status: The status of this User.
        :type: str
        """

        self._status = status

    @property
    def name(self):
        """
        Gets the name of this User.
        name of the user.

        :return: The name of this User.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this User.
        name of the user.

        :param name: The name of this User.
        :type: str
        """

        self._name = name

    @property
    def registered_date(self):
        """
        Gets the registered_date of this User.
        account creation date.

        :return: The registered_date of this User.
        :rtype: datetime
        """
        return self._registered_date

    @registered_date.setter
    def registered_date(self, registered_date):
        """
        Sets the registered_date of this User.
        account creation date.

        :param registered_date: The registered_date of this User.
        :type: datetime
        """

        self._registered_date = registered_date

    @property
    def user_name(self):
        """
        Gets the user_name of this User.
        unique value of the user account.

        :return: The user_name of this User.
        :rtype: str
        """
        return self._user_name

    @user_name.setter
    def user_name(self, user_name):
        """
        Sets the user_name of this User.
        unique value of the user account.

        :param user_name: The user_name of this User.
        :type: str
        """

        self._user_name = user_name

    @property
    def slug(self):
        """
        Gets the slug of this User.
        slug of the user account.

        :return: The slug of this User.
        :rtype: str
        """
        return self._slug

    @slug.setter
    def slug(self, slug):
        """
        Sets the slug of this User.
        slug of the user account.

        :param slug: The slug of this User.
        :type: str
        """

        self._slug = slug

    @property
    def email(self):
        """
        Gets the email of this User.
        email id of user.

        :return: The email of this User.
        :rtype: str
        """
        return self._email

    @email.setter
    def email(self, email):
        """
        Sets the email of this User.
        email id of user.

        :param email: The email of this User.
        :type: str
        """

        self._email = email

    @property
    def accounts(self):
        """
        Gets the accounts of this User.
        user accounts.

        :return: The accounts of this User.
        :rtype: object
        """
        return self._accounts

    @accounts.setter
    def accounts(self, accounts):
        """
        Sets the accounts of this User.
        user accounts.

        :param accounts: The accounts of this User.
        :type: object
        """

        self._accounts = accounts

    @property
    def currentaccount(self):
        """
        Gets the currentaccount of this User.
        user's active account.

        :return: The currentaccount of this User.
        :rtype: object
        """
        return self._currentaccount

    @currentaccount.setter
    def currentaccount(self, currentaccount):
        """
        Sets the currentaccount of this User.
        user's active account.

        :param currentaccount: The currentaccount of this User.
        :type: object
        """

        self._currentaccount = currentaccount

    @property
    def activationchallenge(self):
        """
        Gets the activationchallenge of this User.
        proof of work challenge

        :return: The activationchallenge of this User.
        :rtype: object
        """
        return self._activationchallenge

    @activationchallenge.setter
    def activationchallenge(self, activationchallenge):
        """
        Sets the activationchallenge of this User.
        proof of work challenge

        :param activationchallenge: The activationchallenge of this User.
        :type: object
        """

        self._activationchallenge = activationchallenge

    @property
    def verified(self):
        """
        Gets the verified of this User.
        whether email is verified or not

        :return: The verified of this User.
        :rtype: bool
        """
        return self._verified

    @verified.setter
    def verified(self, verified):
        """
        Sets the verified of this User.
        whether email is verified or not

        :param verified: The verified of this User.
        :type: bool
        """

        self._verified = verified

    @property
    def profile_picture(self):
        """
        Gets the profile_picture of this User.
        if profile picture available it will have url else null

        :return: The profile_picture of this User.
        :rtype: str
        """
        return self._profile_picture

    @profile_picture.setter
    def profile_picture(self, profile_picture):
        """
        Sets the profile_picture of this User.
        if profile picture available it will have url else null

        :param profile_picture: The profile_picture of this User.
        :type: str
        """

        self._profile_picture = profile_picture

    @property
    def subscription(self):
        """
        Gets the subscription of this User.
        subscription type of account. Ex: Free, Paid, Verified or organization

        :return: The subscription of this User.
        :rtype: str
        """
        return self._subscription

    @subscription.setter
    def subscription(self, subscription):
        """
        Sets the subscription of this User.
        subscription type of account. Ex: Free, Paid, Verified or organization

        :param subscription: The subscription of this User.
        :type: str
        """

        self._subscription = subscription

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



# coding: utf-8
# """
# Package version = blended-5.0/swagger_client-1.1.7
# """
# """
#     Swagger Blended Hub API Explorer

#     A collection of Swagger documentation for the Blended Hub APIs.

#     OpenAPI spec version: 1.0.0
#     Contact: api@blended.co
#     Generated by: https://github.com/swagger-api/swagger-codegen.git

#     Licensed under the Apache License, Version 2.0 (the "License");
#     you may not use this file except in compliance with the License.
#     You may obtain a copy of the License at

#         http://www.apache.org/licenses/LICENSE-2.0

#     Unless required by applicable law or agreed to in writing, software
#     distributed under the License is distributed on an "AS IS" BASIS,
#     WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
#     See the License for the specific language governing permissions and
#     limitations under the License.
# """

from __future__ import absolute_import

# import models into sdk package
from .models.account import Account
from .models.account_invite_pending import AccountInvitePending
from .models.account_invites_pending_list import AccountInvitesPendingList
from .models.accounts import Accounts
from .models.acquisition import Acquisition
from .models.acquisition_response import AcquisitionResponse
from .models.acquisition_response_data import AcquisitionResponseData
from .models.activationchallenge import Activationchallenge
from .models.active_account import ActiveAccount
from .models.add_account import AddAccount
from .models.add_admin import AddAdmin
from .models.add_license import AddLicense
from .models.add_pending import AddPending
from .models.add_rating import AddRating
from .models.all_license_price import AllLicensePrice
from .models.blended_package import BlendedPackage
from .models.body import Body
from .models.body_1 import Body1
from .models.bundled_packages import BundledPackages
from .models.bundled_packages_error import BundledPackagesError
from .models.canonical_version import CanonicalVersion
from .models.change_current_account import ChangeCurrentAccount
from .models.change_privilege import ChangePrivilege
from .models.create_account import CreateAccount
from .models.create_canonical import CreateCanonical
from .models.create_package import CreatePackage
from .models.create_version import CreateVersion
from .models.dependencies import Dependencies
from .models.dependencies_list import DependenciesList
from .models.dependency_package_detail import DependencyPackageDetail
from .models.dependency_package_detail_dependency_of_package import DependencyPackageDetailDependencyOfPackage
from .models.documents import Documents
from .models.error import Error
from .models.error_response400 import ErrorResponse400
from .models.error_response401 import ErrorResponse401
from .models.error_response409 import ErrorResponse409
from .models.error_response412 import ErrorResponse412
from .models.error_response500 import ErrorResponse500
from .models.failed_dependency_error import FailedDependencyError
from .models.hyper_link_account import HyperLinkAccount
from .models.hyper_link_canonical_version import HyperLinkCanonicalVersion
from .models.hyper_link_current_account import HyperLinkCurrentAccount
from .models.hyper_link_dependency_packages import HyperLinkDependencyPackages
from .models.hyper_link_draft import HyperLinkDraft
from .models.hyper_link_licenses import HyperLinkLicenses
from .models.hyper_link_pending_user import HyperLinkPendingUser
from .models.hyper_link_ratings import HyperLinkRatings
from .models.hyper_link_user import HyperLinkUser
from .models.hyper_link_validators import HyperLinkValidators
from .models.initial_package import InitialPackage
from .models.initial_packages import InitialPackages
from .models.inline_response_200 import InlineResponse200
from .models.license import License
from .models.like import Like
from .models.login import Login
from .models.logout import Logout
from .models.new_draft import NewDraft
from .models.operands import Operands
from .models.package_detail_data import PackageDetailData
from .models.package_images import PackageImages
from .models.packages import Packages
from .models.pending_user import PendingUser
from .models.pending_users import PendingUsers
from .models.publication import Publication
from .models.publication_error import PublicationError
from .models.publication_validation_error import PublicationValidationError
from .models.publication_version import PublicationVersion
from .models.publication_version_error import PublicationVersionError
from .models.publication_versions import PublicationVersions
from .models.publication_versions_error import PublicationVersionsError
from .models.publications import Publications
from .models.publications_error import PublicationsError
from .models.rating import Rating
from .models.reject_acquisition_package import RejectAcquisitionPackage
from .models.remove_pending import RemovePending
from .models.resend_account_verification_link import ResendAccountVerificationLink
from .models.resend_invite import ResendInvite
from .models.reset_password import ResetPassword
from .models.search_result import SearchResult
from .models.search_results import SearchResults
from .models.session_data import SessionData
from .models.share_approval_list_error import ShareApprovalListError
from .models.shared_package_account import SharedPackageAccount
from .models.shared_package_accounts_list import SharedPackageAccountsList
from .models.update_account import UpdateAccount
from .models.update_draft import UpdateDraft
from .models.update_license import UpdateLicense
from .models.update_package import UpdatePackage
from .models.update_publication import UpdatePublication
from .models.update_version import UpdateVersion
from .models.upload_media import UploadMedia
from .models.user import User
from .models.users import Users
from .models.validator import Validator
from .models.validator_detail import ValidatorDetail
from .models.validator_plan import ValidatorPlan
from .models.validator_sets_in_badge import ValidatorSetsInBadge
from .models.version import Version
from .models.versions import Versions

# import apis into sdk package
from .apis.accounts_api import AccountsApi
from .apis.packages_api import PackagesApi

# import ApiClient
from .api_client import ApiClient

from .configuration import Configuration

configuration = Configuration()



# coding: utf-8

"""
    Swagger Blended Hub API Explorer

    A collection of Swagger documentation for the Blended Hub APIs.

    OpenAPI spec version: 1.0.0
    Contact: api@blended.co
    Generated by: https://github.com/swagger-api/swagger-codegen.git

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.
"""

from __future__ import absolute_import

import sys
import os
import re

# python 2 and python 3 compatibility library
from six import iteritems

from ..configuration import Configuration
from ..api_client import ApiClient


class AccountsApi(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        config = Configuration()
        if api_client:
            self.api_client = api_client
        else:
            if not config.api_client:
                config.api_client = ApiClient()
            self.api_client = config.api_client

    def add_account_admin(self, slug, sessionkey, body, **kwargs):
        """
        Add a admin user into account.
        This can only be done by the logged in user.

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.add_account_admin(slug, sessionkey, body, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str slug: account unique indentifier. (required)
        :param str sessionkey: value used to manage user session. (required)
        :param AddAdmin body: the content of the request used to add admin into account. (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.add_account_admin_with_http_info(slug, sessionkey, body, **kwargs)
        else:
            (data) = self.add_account_admin_with_http_info(slug, sessionkey, body, **kwargs)
            return data

    def add_account_admin_with_http_info(self, slug, sessionkey, body, **kwargs):
        """
        Add a admin user into account.
        This can only be done by the logged in user.

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.add_account_admin_with_http_info(slug, sessionkey, body, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str slug: account unique indentifier. (required)
        :param str sessionkey: value used to manage user session. (required)
        :param AddAdmin body: the content of the request used to add admin into account. (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['slug', 'sessionkey', 'body']
        all_params.append('callback')
        all_params.append('_return_http_data_only')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method add_account_admin" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'slug' is set
        if ('slug' not in params) or (params['slug'] is None):
            raise ValueError("Missing the required parameter `slug` when calling `add_account_admin`")
        # verify the required parameter 'sessionkey' is set
        if ('sessionkey' not in params) or (params['sessionkey'] is None):
            raise ValueError("Missing the required parameter `sessionkey` when calling `add_account_admin`")
        # verify the required parameter 'body' is set
        if ('body' not in params) or (params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `add_account_admin`")

        resource_path = '/accounts/{slug}/admins/'.replace('{format}', 'json')
        path_params = {}
        if 'slug' in params:
            path_params['slug'] = params['slug']

        query_params = {}

        header_params = {}
        if 'sessionkey' in params:
            header_params['sessionkey'] = params['sessionkey']

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']

        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])
        if not header_params['Accept']:
            del header_params['Accept']

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json'])

        # Authentication setting
        auth_settings = []

        return self.api_client.call_api(resource_path, 'POST',
                                            path_params,
                                            query_params,
                                            header_params,
                                            body=body_params,
                                            post_params=form_params,
                                            files=local_var_files,
                                            response_type=None,
                                            auth_settings=auth_settings,
                                            callback=params.get('callback'),
                                            _return_http_data_only=params.get('_return_http_data_only'))

    def add_account_user(self, slug, sessionkey, body, **kwargs):
        """
        Add a regular user into account.
        This can only be done by the logged in user.

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.add_account_user(slug, sessionkey, body, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str slug: account unique indentifier. (required)
        :param str sessionkey: value used to manage user session. (required)
        :param AddAdmin body: the content of the request used to add admin into account. (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.add_account_user_with_http_info(slug, sessionkey, body, **kwargs)
        else:
            (data) = self.add_account_user_with_http_info(slug, sessionkey, body, **kwargs)
            return data

    def add_account_user_with_http_info(self, slug, sessionkey, body, **kwargs):
        """
        Add a regular user into account.
        This can only be done by the logged in user.

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.add_account_user_with_http_info(slug, sessionkey, body, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str slug: account unique indentifier. (required)
        :param str sessionkey: value used to manage user session. (required)
        :param AddAdmin body: the content of the request used to add admin into account. (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['slug', 'sessionkey', 'body']
        all_params.append('callback')
        all_params.append('_return_http_data_only')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method add_account_user" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'slug' is set
        if ('slug' not in params) or (params['slug'] is None):
            raise ValueError("Missing the required parameter `slug` when calling `add_account_user`")
        # verify the required parameter 'sessionkey' is set
        if ('sessionkey' not in params) or (params['sessionkey'] is None):
            raise ValueError("Missing the required parameter `sessionkey` when calling `add_account_user`")
        # verify the required parameter 'body' is set
        if ('body' not in params) or (params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `add_account_user`")

        resource_path = '/accounts/{slug}/users/'.replace('{format}', 'json')
        path_params = {}
        if 'slug' in params:
            path_params['slug'] = params['slug']

        query_params = {}

        header_params = {}
        if 'sessionkey' in params:
            header_params['sessionkey'] = params['sessionkey']

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']

        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])
        if not header_params['Accept']:
            del header_params['Accept']

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json'])

        # Authentication setting
        auth_settings = []

        return self.api_client.call_api(resource_path, 'POST',
                                            path_params,
                                            query_params,
                                            header_params,
                                            body=body_params,
                                            post_params=form_params,
                                            files=local_var_files,
                                            response_type=None,
                                            auth_settings=auth_settings,
                                            callback=params.get('callback'),
                                            _return_http_data_only=params.get('_return_http_data_only'))

    def change_account_user_privilege(self, slug, user_slug, sessionkey, body, **kwargs):
        """
        account Regular user.
        This can only be done by the logged in user.

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.change_account_user_privilege(slug, user_slug, sessionkey, body, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str slug: account unique indentifier. (required)
        :param str user_slug: user account unique indentifier. (required)
        :param str sessionkey: value used to manage user session. (required)
        :param ChangePrivilege body: the content of the request used to add admin into account. (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.change_account_user_privilege_with_http_info(slug, user_slug, sessionkey, body, **kwargs)
        else:
            (data) = self.change_account_user_privilege_with_http_info(slug, user_slug, sessionkey, body, **kwargs)
            return data

    def change_account_user_privilege_with_http_info(self, slug, user_slug, sessionkey, body, **kwargs):
        """
        account Regular user.
        This can only be done by the logged in user.

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.change_account_user_privilege_with_http_info(slug, user_slug, sessionkey, body, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str slug: account unique indentifier. (required)
        :param str user_slug: user account unique indentifier. (required)
        :param str sessionkey: value used to manage user session. (required)
        :param ChangePrivilege body: the content of the request used to add admin into account. (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['slug', 'user_slug', 'sessionkey', 'body']
        all_params.append('callback')
        all_params.append('_return_http_data_only')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method change_account_user_privilege" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'slug' is set
        if ('slug' not in params) or (params['slug'] is None):
            raise ValueError("Missing the required parameter `slug` when calling `change_account_user_privilege`")
        # verify the required parameter 'user_slug' is set
        if ('user_slug' not in params) or (params['user_slug'] is None):
            raise ValueError("Missing the required parameter `user_slug` when calling `change_account_user_privilege`")
        # verify the required parameter 'sessionkey' is set
        if ('sessionkey' not in params) or (params['sessionkey'] is None):
            raise ValueError("Missing the required parameter `sessionkey` when calling `change_account_user_privilege`")
        # verify the required parameter 'body' is set
        if ('body' not in params) or (params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `change_account_user_privilege`")

        resource_path = '/accounts/{slug}/users/{user_slug}/'.replace('{format}', 'json')
        path_params = {}
        if 'slug' in params:
            path_params['slug'] = params['slug']
        if 'user_slug' in params:
            path_params['user_slug'] = params['user_slug']

        query_params = {}

        header_params = {}
        if 'sessionkey' in params:
            header_params['sessionkey'] = params['sessionkey']

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']

        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])
        if not header_params['Accept']:
            del header_params['Accept']

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json'])

        # Authentication setting
        auth_settings = []

        return self.api_client.call_api(resource_path, 'PUT',
                                            path_params,
                                            query_params,
                                            header_params,
                                            body=body_params,
                                            post_params=form_params,
                                            files=local_var_files,
                                            response_type=None,
                                            auth_settings=auth_settings,
                                            callback=params.get('callback'),
                                            _return_http_data_only=params.get('_return_http_data_only'))

    def create_account(self, body, **kwargs):
        """
        Create a new user account.
        

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.create_account(body, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param CreateAccount body: the content of the request used to create user account. (required)
        :param str verbose: parameter to provide detail view of hyperlink objects.
        :return: User
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.create_account_with_http_info(body, **kwargs)
        else:
            (data) = self.create_account_with_http_info(body, **kwargs)
            return data

    def create_account_with_http_info(self, body, **kwargs):
        """
        Create a new user account.
        

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.create_account_with_http_info(body, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param CreateAccount body: the content of the request used to create user account. (required)
        :param str verbose: parameter to provide detail view of hyperlink objects.
        :return: User
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body', 'verbose']
        all_params.append('callback')
        all_params.append('_return_http_data_only')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method create_account" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if ('body' not in params) or (params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `create_account`")

        resource_path = '/accounts/'.replace('{format}', 'json')
        path_params = {}

        query_params = {}
        if 'verbose' in params:
            query_params['verbose'] = params['verbose']

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']

        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])
        if not header_params['Accept']:
            del header_params['Accept']

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json'])

        # Authentication setting
        auth_settings = []

        return self.api_client.call_api(resource_path, 'POST',
                                            path_params,
                                            query_params,
                                            header_params,
                                            body=body_params,
                                            post_params=form_params,
                                            files=local_var_files,
                                            response_type='User',
                                            auth_settings=auth_settings,
                                            callback=params.get('callback'),
                                            _return_http_data_only=params.get('_return_http_data_only'))

    def get_account_admin(self, slug, admin_slug, sessionkey, **kwargs):
        """
        Get account Admin.
        This can only be done by the logged in user.

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.get_account_admin(slug, admin_slug, sessionkey, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str slug: account unique indentifier. (required)
        :param str admin_slug: admin account unique indentifier. (required)
        :param str sessionkey: user session. (required)
        :param str verbose: parameter to provide detail view of hyperlink objects.
        :return: User
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.get_account_admin_with_http_info(slug, admin_slug, sessionkey, **kwargs)
        else:
            (data) = self.get_account_admin_with_http_info(slug, admin_slug, sessionkey, **kwargs)
            return data

    def get_account_admin_with_http_info(self, slug, admin_slug, sessionkey, **kwargs):
        """
        Get account Admin.
        This can only be done by the logged in user.

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.get_account_admin_with_http_info(slug, admin_slug, sessionkey, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str slug: account unique indentifier. (required)
        :param str admin_slug: admin account unique indentifier. (required)
        :param str sessionkey: user session. (required)
        :param str verbose: parameter to provide detail view of hyperlink objects.
        :return: User
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['slug', 'admin_slug', 'sessionkey', 'verbose']
        all_params.append('callback')
        all_params.append('_return_http_data_only')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_account_admin" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'slug' is set
        if ('slug' not in params) or (params['slug'] is None):
            raise ValueError("Missing the required parameter `slug` when calling `get_account_admin`")
        # verify the required parameter 'admin_slug' is set
        if ('admin_slug' not in params) or (params['admin_slug'] is None):
            raise ValueError("Missing the required parameter `admin_slug` when calling `get_account_admin`")
        # verify the required parameter 'sessionkey' is set
        if ('sessionkey' not in params) or (params['sessionkey'] is None):
            raise ValueError("Missing the required parameter `sessionkey` when calling `get_account_admin`")

        resource_path = '/accounts/{slug}/admins/{admin_slug}/'.replace('{format}', 'json')
        path_params = {}
        if 'slug' in params:
            path_params['slug'] = params['slug']
        if 'admin_slug' in params:
            path_params['admin_slug'] = params['admin_slug']

        query_params = {}
        if 'verbose' in params:
            query_params['verbose'] = params['verbose']

        header_params = {}
        if 'sessionkey' in params:
            header_params['sessionkey'] = params['sessionkey']

        form_params = []
        local_var_files = {}

        body_params = None

        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])
        if not header_params['Accept']:
            del header_params['Accept']

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json'])

        # Authentication setting
        auth_settings = []

        return self.api_client.call_api(resource_path, 'GET',
                                            path_params,
                                            query_params,
                                            header_params,
                                            body=body_params,
                                            post_params=form_params,
                                            files=local_var_files,
                                            response_type='User',
                                            auth_settings=auth_settings,
                                            callback=params.get('callback'),
                                            _return_http_data_only=params.get('_return_http_data_only'))

    def get_account_admins(self, slug, sessionkey, **kwargs):
        """
        get admin users of account.
        This can only be done by the logged in user.

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.get_account_admins(slug, sessionkey, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str slug: account unique indentifier. (required)
        :param str sessionkey: value used to manage user session. (required)
        :param str verbose: parameter to provide detail view of hyperlink objects.
        :return: Users
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.get_account_admins_with_http_info(slug, sessionkey, **kwargs)
        else:
            (data) = self.get_account_admins_with_http_info(slug, sessionkey, **kwargs)
            return data

    def get_account_admins_with_http_info(self, slug, sessionkey, **kwargs):
        """
        get admin users of account.
        This can only be done by the logged in user.

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.get_account_admins_with_http_info(slug, sessionkey, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str slug: account unique indentifier. (required)
        :param str sessionkey: value used to manage user session. (required)
        :param str verbose: parameter to provide detail view of hyperlink objects.
        :return: Users
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['slug', 'sessionkey', 'verbose']
        all_params.append('callback')
        all_params.append('_return_http_data_only')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_account_admins" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'slug' is set
        if ('slug' not in params) or (params['slug'] is None):
            raise ValueError("Missing the required parameter `slug` when calling `get_account_admins`")
        # verify the required parameter 'sessionkey' is set
        if ('sessionkey' not in params) or (params['sessionkey'] is None):
            raise ValueError("Missing the required parameter `sessionkey` when calling `get_account_admins`")

        resource_path = '/accounts/{slug}/admins/'.replace('{format}', 'json')
        path_params = {}
        if 'slug' in params:
            path_params['slug'] = params['slug']

        query_params = {}
        if 'verbose' in params:
            query_params['verbose'] = params['verbose']

        header_params = {}
        if 'sessionkey' in params:
            header_params['sessionkey'] = params['sessionkey']

        form_params = []
        local_var_files = {}

        body_params = None

        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])
        if not header_params['Accept']:
            del header_params['Accept']

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json'])

        # Authentication setting
        auth_settings = []

        return self.api_client.call_api(resource_path, 'GET',
                                            path_params,
                                            query_params,
                                            header_params,
                                            body=body_params,
                                            post_params=form_params,
                                            files=local_var_files,
                                            response_type='Users',
                                            auth_settings=auth_settings,
                                            callback=params.get('callback'),
                                            _return_http_data_only=params.get('_return_http_data_only'))

    def get_account_details(self, slug, sessionkey, **kwargs):
        """
        Detail View of user account.
        user should be logged in to see detail view of account.

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.get_account_details(slug, sessionkey, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str slug: unique value which will be used to fetch user account details. (required)
        :param str sessionkey: account session. (required)
        :param str verbose: parameter to provide detail view of hyperlink objects.
        :return: User
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.get_account_details_with_http_info(slug, sessionkey, **kwargs)
        else:
            (data) = self.get_account_details_with_http_info(slug, sessionkey, **kwargs)
            return data

    def get_account_details_with_http_info(self, slug, sessionkey, **kwargs):
        """
        Detail View of user account.
        user should be logged in to see detail view of account.

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.get_account_details_with_http_info(slug, sessionkey, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str slug: unique value which will be used to fetch user account details. (required)
        :param str sessionkey: account session. (required)
        :param str verbose: parameter to provide detail view of hyperlink objects.
        :return: User
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['slug', 'sessionkey', 'verbose']
        all_params.append('callback')
        all_params.append('_return_http_data_only')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_account_details" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'slug' is set
        if ('slug' not in params) or (params['slug'] is None):
            raise ValueError("Missing the required parameter `slug` when calling `get_account_details`")
        # verify the required parameter 'sessionkey' is set
        if ('sessionkey' not in params) or (params['sessionkey'] is None):
            raise ValueError("Missing the required parameter `sessionkey` when calling `get_account_details`")

        resource_path = '/accounts/{slug}/'.replace('{format}', 'json')
        path_params = {}
        if 'slug' in params:
            path_params['slug'] = params['slug']

        query_params = {}
        if 'verbose' in params:
            query_params['verbose'] = params['verbose']

        header_params = {}
        if 'sessionkey' in params:
            header_params['sessionkey'] = params['sessionkey']

        form_params = []
        local_var_files = {}

        body_params = None

        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])
        if not header_params['Accept']:
            del header_params['Accept']

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json'])

        # Authentication setting
        auth_settings = []

        return self.api_client.call_api(resource_path, 'GET',
                                            path_params,
                                            query_params,
                                            header_params,
                                            body=body_params,
                                            post_params=form_params,
                                            files=local_var_files,
                                            response_type='User',
                                            auth_settings=auth_settings,
                                            callback=params.get('callback'),
                                            _return_http_data_only=params.get('_return_http_data_only'))

    def get_account_invites_pending_list(self, slug, sessionkey, **kwargs):
        """
        To get the List of all accounts who invite the user and request is pending to accept or reject.
        This can only be done by the logged in user.

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.get_account_invites_pending_list(slug, sessionkey, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str slug: account unique indentifier. (required)
        :param str sessionkey: value used to manage user session. (required)
        :return: AccountInvitesPendingList
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.get_account_invites_pending_list_with_http_info(slug, sessionkey, **kwargs)
        else:
            (data) = self.get_account_invites_pending_list_with_http_info(slug, sessionkey, **kwargs)
            return data

    def get_account_invites_pending_list_with_http_info(self, slug, sessionkey, **kwargs):
        """
        To get the List of all accounts who invite the user and request is pending to accept or reject.
        This can only be done by the logged in user.

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.get_account_invites_pending_list_with_http_info(slug, sessionkey, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str slug: account unique indentifier. (required)
        :param str sessionkey: value used to manage user session. (required)
        :return: AccountInvitesPendingList
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['slug', 'sessionkey']
        all_params.append('callback')
        all_params.append('_return_http_data_only')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_account_invites_pending_list" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'slug' is set
        if ('slug' not in params) or (params['slug'] is None):
            raise ValueError("Missing the required parameter `slug` when calling `get_account_invites_pending_list`")
        # verify the required parameter 'sessionkey' is set
        if ('sessionkey' not in params) or (params['sessionkey'] is None):
            raise ValueError("Missing the required parameter `sessionkey` when calling `get_account_invites_pending_list`")

        resource_path = '/accounts/{slug}/accountpendings/'.replace('{format}', 'json')
        path_params = {}
        if 'slug' in params:
            path_params['slug'] = params['slug']

        query_params = {}

        header_params = {}
        if 'sessionkey' in params:
            header_params['sessionkey'] = params['sessionkey']

        form_params = []
        local_var_files = {}

        body_params = None

        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])
        if not header_params['Accept']:
            del header_params['Accept']

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json'])

        # Authentication setting
        auth_settings = []

        return self.api_client.call_api(resource_path, 'GET',
                                            path_params,
                                            query_params,
                                            header_params,
                                            body=body_params,
                                            post_params=form_params,
                                            files=local_var_files,
                                            response_type='AccountInvitesPendingList',
                                            auth_settings=auth_settings,
                                            callback=params.get('callback'),
                                            _return_http_data_only=params.get('_return_http_data_only'))

    def get_account_list(self, sessionkey, slug, **kwargs):
        """
        Returns all accounts from the system that the user has access to.
        

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.get_account_list(sessionkey, slug, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str sessionkey: value used to manage user session. (required)
        :param str slug: unique value which will be used to fetch user account details. (required)
        :param str verbose: parameter to provide detail view of hyperlink objects.
        :return: Accounts
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.get_account_list_with_http_info(sessionkey, slug, **kwargs)
        else:
            (data) = self.get_account_list_with_http_info(sessionkey, slug, **kwargs)
            return data

    def get_account_list_with_http_info(self, sessionkey, slug, **kwargs):
        """
        Returns all accounts from the system that the user has access to.
        

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.get_account_list_with_http_info(sessionkey, slug, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str sessionkey: value used to manage user session. (required)
        :param str slug: unique value which will be used to fetch user account details. (required)
        :param str verbose: parameter to provide detail view of hyperlink objects.
        :return: Accounts
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['sessionkey', 'slug', 'verbose']
        all_params.append('callback')
        all_params.append('_return_http_data_only')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_account_list" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'sessionkey' is set
        if ('sessionkey' not in params) or (params['sessionkey'] is None):
            raise ValueError("Missing the required parameter `sessionkey` when calling `get_account_list`")
        # verify the required parameter 'slug' is set
        if ('slug' not in params) or (params['slug'] is None):
            raise ValueError("Missing the required parameter `slug` when calling `get_account_list`")

        resource_path = '/accounts/{slug}/accounts/'.replace('{format}', 'json')
        path_params = {}
        if 'slug' in params:
            path_params['slug'] = params['slug']

        query_params = {}
        if 'verbose' in params:
            query_params['verbose'] = params['verbose']

        header_params = {}
        if 'sessionkey' in params:
            header_params['sessionkey'] = params['sessionkey']

        form_params = []
        local_var_files = {}

        body_params = None

        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])
        if not header_params['Accept']:
            del header_params['Accept']

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json'])

        # Authentication setting
        auth_settings = []

        return self.api_client.call_api(resource_path, 'GET',
                                            path_params,
                                            query_params,
                                            header_params,
                                            body=body_params,
                                            post_params=form_params,
                                            files=local_var_files,
                                            response_type='Accounts',
                                            auth_settings=auth_settings,
                                            callback=params.get('callback'),
                                            _return_http_data_only=params.get('_return_http_data_only'))

    def get_account_user(self, slug, user_slug, sessionkey, **kwargs):
        """
        account Regular user.
        This can only be done by the logged in user.

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.get_account_user(slug, user_slug, sessionkey, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str slug: account unique indentifier. (required)
        :param str user_slug: user account unique indentifier. (required)
        :param str sessionkey: value used to manage user session. (required)
        :param str verbose: parameter to provide detail view of hyperlink objects.
        :return: User
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.get_account_user_with_http_info(slug, user_slug, sessionkey, **kwargs)
        else:
            (data) = self.get_account_user_with_http_info(slug, user_slug, sessionkey, **kwargs)
            return data

    def get_account_user_with_http_info(self, slug, user_slug, sessionkey, **kwargs):
        """
        account Regular user.
        This can only be done by the logged in user.

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.get_account_user_with_http_info(slug, user_slug, sessionkey, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str slug: account unique indentifier. (required)
        :param str user_slug: user account unique indentifier. (required)
        :param str sessionkey: value used to manage user session. (required)
        :param str verbose: parameter to provide detail view of hyperlink objects.
        :return: User
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['slug', 'user_slug', 'sessionkey', 'verbose']
        all_params.append('callback')
        all_params.append('_return_http_data_only')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_account_user" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'slug' is set
        if ('slug' not in params) or (params['slug'] is None):
            raise ValueError("Missing the required parameter `slug` when calling `get_account_user`")
        # verify the required parameter 'user_slug' is set
        if ('user_slug' not in params) or (params['user_slug'] is None):
            raise ValueError("Missing the required parameter `user_slug` when calling `get_account_user`")
        # verify the required parameter 'sessionkey' is set
        if ('sessionkey' not in params) or (params['sessionkey'] is None):
            raise ValueError("Missing the required parameter `sessionkey` when calling `get_account_user`")

        resource_path = '/accounts/{slug}/users/{user_slug}/'.replace('{format}', 'json')
        path_params = {}
        if 'slug' in params:
            path_params['slug'] = params['slug']
        if 'user_slug' in params:
            path_params['user_slug'] = params['user_slug']

        query_params = {}
        if 'verbose' in params:
            query_params['verbose'] = params['verbose']

        header_params = {}
        if 'sessionkey' in params:
            header_params['sessionkey'] = params['sessionkey']

        form_params = []
        local_var_files = {}

        body_params = None

        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])
        if not header_params['Accept']:
            del header_params['Accept']

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json'])

        # Authentication setting
        auth_settings = []

        return self.api_client.call_api(resource_path, 'GET',
                                            path_params,
                                            query_params,
                                            header_params,
                                            body=body_params,
                                            post_params=form_params,
                                            files=local_var_files,
                                            response_type='User',
                                            auth_settings=auth_settings,
                                            callback=params.get('callback'),
                                            _return_http_data_only=params.get('_return_http_data_only'))

    def get_account_users(self, slug, sessionkey, **kwargs):
        """
        get Regular Users of account.
        This can only be done by the logged in user.

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.get_account_users(slug, sessionkey, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str slug: account unique indentifier. (required)
        :param str sessionkey: value used to manage user session. (required)
        :param str verbose: parameter to provide detail view of hyperlink objects.
        :return: Users
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.get_account_users_with_http_info(slug, sessionkey, **kwargs)
        else:
            (data) = self.get_account_users_with_http_info(slug, sessionkey, **kwargs)
            return data

    def get_account_users_with_http_info(self, slug, sessionkey, **kwargs):
        """
        get Regular Users of account.
        This can only be done by the logged in user.

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.get_account_users_with_http_info(slug, sessionkey, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str slug: account unique indentifier. (required)
        :param str sessionkey: value used to manage user session. (required)
        :param str verbose: parameter to provide detail view of hyperlink objects.
        :return: Users
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['slug', 'sessionkey', 'verbose']
        all_params.append('callback')
        all_params.append('_return_http_data_only')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_account_users" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'slug' is set
        if ('slug' not in params) or (params['slug'] is None):
            raise ValueError("Missing the required parameter `slug` when calling `get_account_users`")
        # verify the required parameter 'sessionkey' is set
        if ('sessionkey' not in params) or (params['sessionkey'] is None):
            raise ValueError("Missing the required parameter `sessionkey` when calling `get_account_users`")

        resource_path = '/accounts/{slug}/users/'.replace('{format}', 'json')
        path_params = {}
        if 'slug' in params:
            path_params['slug'] = params['slug']

        query_params = {}
        if 'verbose' in params:
            query_params['verbose'] = params['verbose']

        header_params = {}
        if 'sessionkey' in params:
            header_params['sessionkey'] = params['sessionkey']

        form_params = []
        local_var_files = {}

        body_params = None

        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])
        if not header_params['Accept']:
            del header_params['Accept']

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json'])

        # Authentication setting
        auth_settings = []

        return self.api_client.call_api(resource_path, 'GET',
                                            path_params,
                                            query_params,
                                            header_params,
                                            body=body_params,
                                            post_params=form_params,
                                            files=local_var_files,
                                            response_type='Users',
                                            auth_settings=auth_settings,
                                            callback=params.get('callback'),
                                            _return_http_data_only=params.get('_return_http_data_only'))

    def get_current_account(self, slug, sessionkey, **kwargs):
        """
        Get current user account.
        

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.get_current_account(slug, sessionkey, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str slug: unique value which will be used to fetch user account details. (required)
        :param str sessionkey: value used to manage user session. (required)
        :param str verbose: parameter to provide detail view of hyperlink objects.
        :return: Account
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.get_current_account_with_http_info(slug, sessionkey, **kwargs)
        else:
            (data) = self.get_current_account_with_http_info(slug, sessionkey, **kwargs)
            return data

    def get_current_account_with_http_info(self, slug, sessionkey, **kwargs):
        """
        Get current user account.
        

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.get_current_account_with_http_info(slug, sessionkey, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str slug: unique value which will be used to fetch user account details. (required)
        :param str sessionkey: value used to manage user session. (required)
        :param str verbose: parameter to provide detail view of hyperlink objects.
        :return: Account
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['slug', 'sessionkey', 'verbose']
        all_params.append('callback')
        all_params.append('_return_http_data_only')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_current_account" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'slug' is set
        if ('slug' not in params) or (params['slug'] is None):
            raise ValueError("Missing the required parameter `slug` when calling `get_current_account`")
        # verify the required parameter 'sessionkey' is set
        if ('sessionkey' not in params) or (params['sessionkey'] is None):
            raise ValueError("Missing the required parameter `sessionkey` when calling `get_current_account`")

        resource_path = '/accounts/{slug}/current/'.replace('{format}', 'json')
        path_params = {}
        if 'slug' in params:
            path_params['slug'] = params['slug']

        query_params = {}
        if 'verbose' in params:
            query_params['verbose'] = params['verbose']

        header_params = {}
        if 'sessionkey' in params:
            header_params['sessionkey'] = params['sessionkey']

        form_params = []
        local_var_files = {}

        body_params = None

        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])
        if not header_params['Accept']:
            del header_params['Accept']

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json'])

        # Authentication setting
        auth_settings = []

        return self.api_client.call_api(resource_path, 'GET',
                                            path_params,
                                            query_params,
                                            header_params,
                                            body=body_params,
                                            post_params=form_params,
                                            files=local_var_files,
                                            response_type='Account',
                                            auth_settings=auth_settings,
                                            callback=params.get('callback'),
                                            _return_http_data_only=params.get('_return_http_data_only'))

    def get_pending_users(self, slug, sessionkey, **kwargs):
        """
        Get list of user's account pending users.
        

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.get_pending_users(slug, sessionkey, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str slug: account unique indentifier. (required)
        :param str sessionkey: value used to manage user session. (required)
        :param str verbose: parameter to provide detail view of hyperlink objects.
        :return: PendingUsers
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.get_pending_users_with_http_info(slug, sessionkey, **kwargs)
        else:
            (data) = self.get_pending_users_with_http_info(slug, sessionkey, **kwargs)
            return data

    def get_pending_users_with_http_info(self, slug, sessionkey, **kwargs):
        """
        Get list of user's account pending users.
        

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.get_pending_users_with_http_info(slug, sessionkey, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str slug: account unique indentifier. (required)
        :param str sessionkey: value used to manage user session. (required)
        :param str verbose: parameter to provide detail view of hyperlink objects.
        :return: PendingUsers
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['slug', 'sessionkey', 'verbose']
        all_params.append('callback')
        all_params.append('_return_http_data_only')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_pending_users" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'slug' is set
        if ('slug' not in params) or (params['slug'] is None):
            raise ValueError("Missing the required parameter `slug` when calling `get_pending_users`")
        # verify the required parameter 'sessionkey' is set
        if ('sessionkey' not in params) or (params['sessionkey'] is None):
            raise ValueError("Missing the required parameter `sessionkey` when calling `get_pending_users`")

        resource_path = '/accounts/{slug}/pendings/'.replace('{format}', 'json')
        path_params = {}
        if 'slug' in params:
            path_params['slug'] = params['slug']

        query_params = {}
        if 'verbose' in params:
            query_params['verbose'] = params['verbose']

        header_params = {}
        if 'sessionkey' in params:
            header_params['sessionkey'] = params['sessionkey']

        form_params = []
        local_var_files = {}

        body_params = None

        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])
        if not header_params['Accept']:
            del header_params['Accept']

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json'])

        # Authentication setting
        auth_settings = []

        return self.api_client.call_api(resource_path, 'GET',
                                            path_params,
                                            query_params,
                                            header_params,
                                            body=body_params,
                                            post_params=form_params,
                                            files=local_var_files,
                                            response_type='PendingUsers',
                                            auth_settings=auth_settings,
                                            callback=params.get('callback'),
                                            _return_http_data_only=params.get('_return_http_data_only'))

    def invite_user(self, slug, sessionkey, body, **kwargs):
        """
        Invite user to join account.
        This can only be done by the logged in user.

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.invite_user(slug, sessionkey, body, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str slug: account unique indentifier. (required)
        :param str sessionkey: user session. (required)
        :param AddPending body: the content of the request used to add admin into user account. (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.invite_user_with_http_info(slug, sessionkey, body, **kwargs)
        else:
            (data) = self.invite_user_with_http_info(slug, sessionkey, body, **kwargs)
            return data

    def invite_user_with_http_info(self, slug, sessionkey, body, **kwargs):
        """
        Invite user to join account.
        This can only be done by the logged in user.

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.invite_user_with_http_info(slug, sessionkey, body, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str slug: account unique indentifier. (required)
        :param str sessionkey: user session. (required)
        :param AddPending body: the content of the request used to add admin into user account. (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['slug', 'sessionkey', 'body']
        all_params.append('callback')
        all_params.append('_return_http_data_only')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method invite_user" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'slug' is set
        if ('slug' not in params) or (params['slug'] is None):
            raise ValueError("Missing the required parameter `slug` when calling `invite_user`")
        # verify the required parameter 'sessionkey' is set
        if ('sessionkey' not in params) or (params['sessionkey'] is None):
            raise ValueError("Missing the required parameter `sessionkey` when calling `invite_user`")
        # verify the required parameter 'body' is set
        if ('body' not in params) or (params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `invite_user`")

        resource_path = '/accounts/{slug}/pendings/'.replace('{format}', 'json')
        path_params = {}
        if 'slug' in params:
            path_params['slug'] = params['slug']

        query_params = {}

        header_params = {}
        if 'sessionkey' in params:
            header_params['sessionkey'] = params['sessionkey']

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']

        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])
        if not header_params['Accept']:
            del header_params['Accept']

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json'])

        # Authentication setting
        auth_settings = []

        return self.api_client.call_api(resource_path, 'POST',
                                            path_params,
                                            query_params,
                                            header_params,
                                            body=body_params,
                                            post_params=form_params,
                                            files=local_var_files,
                                            response_type=None,
                                            auth_settings=auth_settings,
                                            callback=params.get('callback'),
                                            _return_http_data_only=params.get('_return_http_data_only'))

    def leave_account(self, slug, sessionkey, **kwargs):
        """
        Returns all accounts from the system that the user has access to.
        

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.leave_account(slug, sessionkey, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str slug: unique value account slug which user wants to leave. (required)
        :param str sessionkey: value used to manage user session. (required)
        :param str verbose: parameter to provide detail view of hyperlink objects.
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.leave_account_with_http_info(slug, sessionkey, **kwargs)
        else:
            (data) = self.leave_account_with_http_info(slug, sessionkey, **kwargs)
            return data

    def leave_account_with_http_info(self, slug, sessionkey, **kwargs):
        """
        Returns all accounts from the system that the user has access to.
        

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.leave_account_with_http_info(slug, sessionkey, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str slug: unique value account slug which user wants to leave. (required)
        :param str sessionkey: value used to manage user session. (required)
        :param str verbose: parameter to provide detail view of hyperlink objects.
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['slug', 'sessionkey', 'verbose']
        all_params.append('callback')
        all_params.append('_return_http_data_only')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method leave_account" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'slug' is set
        if ('slug' not in params) or (params['slug'] is None):
            raise ValueError("Missing the required parameter `slug` when calling `leave_account`")
        # verify the required parameter 'sessionkey' is set
        if ('sessionkey' not in params) or (params['sessionkey'] is None):
            raise ValueError("Missing the required parameter `sessionkey` when calling `leave_account`")

        resource_path = '/accounts/{slug}/accounts/'.replace('{format}', 'json')
        path_params = {}
        if 'slug' in params:
            path_params['slug'] = params['slug']

        query_params = {}
        if 'verbose' in params:
            query_params['verbose'] = params['verbose']

        header_params = {}
        if 'sessionkey' in params:
            header_params['sessionkey'] = params['sessionkey']

        form_params = []
        local_var_files = {}

        body_params = None

        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])
        if not header_params['Accept']:
            del header_params['Accept']

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json'])

        # Authentication setting
        auth_settings = []

        return self.api_client.call_api(resource_path, 'DELETE',
                                            path_params,
                                            query_params,
                                            header_params,
                                            body=body_params,
                                            post_params=form_params,
                                            files=local_var_files,
                                            response_type=None,
                                            auth_settings=auth_settings,
                                            callback=params.get('callback'),
                                            _return_http_data_only=params.get('_return_http_data_only'))

    def login(self, body, **kwargs):
        """
        Logs user account into the system.
        

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.login(body, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param Login body: The request data used to login. (required)
        :return: SessionData
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.login_with_http_info(body, **kwargs)
        else:
            (data) = self.login_with_http_info(body, **kwargs)
            return data

    def login_with_http_info(self, body, **kwargs):
        """
        Logs user account into the system.
        

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.login_with_http_info(body, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param Login body: The request data used to login. (required)
        :return: SessionData
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body']
        all_params.append('callback')
        all_params.append('_return_http_data_only')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method login" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if ('body' not in params) or (params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `login`")

        resource_path = '/login/'.replace('{format}', 'json')
        path_params = {}

        query_params = {}

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']

        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])
        if not header_params['Accept']:
            del header_params['Accept']

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json'])

        # Authentication setting
        auth_settings = []

        return self.api_client.call_api(resource_path, 'POST',
                                            path_params,
                                            query_params,
                                            header_params,
                                            body=body_params,
                                            post_params=form_params,
                                            files=local_var_files,
                                            response_type='SessionData',
                                            auth_settings=auth_settings,
                                            callback=params.get('callback'),
                                            _return_http_data_only=params.get('_return_http_data_only'))

    def logout(self, body, **kwargs):
        """
        Logs out current logged in user account session.
        

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.logout(body, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param Logout body: The request data used to logout. (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.logout_with_http_info(body, **kwargs)
        else:
            (data) = self.logout_with_http_info(body, **kwargs)
            return data

    def logout_with_http_info(self, body, **kwargs):
        """
        Logs out current logged in user account session.
        

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.logout_with_http_info(body, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param Logout body: The request data used to logout. (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body']
        all_params.append('callback')
        all_params.append('_return_http_data_only')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method logout" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if ('body' not in params) or (params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `logout`")

        resource_path = '/logout/'.replace('{format}', 'json')
        path_params = {}

        query_params = {}

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']

        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])
        if not header_params['Accept']:
            del header_params['Accept']

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json'])

        # Authentication setting
        auth_settings = []

        return self.api_client.call_api(resource_path, 'POST',
                                            path_params,
                                            query_params,
                                            header_params,
                                            body=body_params,
                                            post_params=form_params,
                                            files=local_var_files,
                                            response_type=None,
                                            auth_settings=auth_settings,
                                            callback=params.get('callback'),
                                            _return_http_data_only=params.get('_return_http_data_only'))

    def reject_user_invite(self, slug, sessionkey, **kwargs):
        """
        Reject User invitation of account.
        This can only be done by the logged in user.

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.reject_user_invite(slug, sessionkey, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str slug: account unique indentifier from which logged in user got the invitation. (required)
        :param str sessionkey: value used to manage user session. (required)
        :param str verbose: parameter to provide detail view of hyperlink objects.
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.reject_user_invite_with_http_info(slug, sessionkey, **kwargs)
        else:
            (data) = self.reject_user_invite_with_http_info(slug, sessionkey, **kwargs)
            return data

    def reject_user_invite_with_http_info(self, slug, sessionkey, **kwargs):
        """
        Reject User invitation of account.
        This can only be done by the logged in user.

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.reject_user_invite_with_http_info(slug, sessionkey, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str slug: account unique indentifier from which logged in user got the invitation. (required)
        :param str sessionkey: value used to manage user session. (required)
        :param str verbose: parameter to provide detail view of hyperlink objects.
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['slug', 'sessionkey', 'verbose']
        all_params.append('callback')
        all_params.append('_return_http_data_only')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method reject_user_invite" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'slug' is set
        if ('slug' not in params) or (params['slug'] is None):
            raise ValueError("Missing the required parameter `slug` when calling `reject_user_invite`")
        # verify the required parameter 'sessionkey' is set
        if ('sessionkey' not in params) or (params['sessionkey'] is None):
            raise ValueError("Missing the required parameter `sessionkey` when calling `reject_user_invite`")

        resource_path = '/accounts/{slug}/users/'.replace('{format}', 'json')
        path_params = {}
        if 'slug' in params:
            path_params['slug'] = params['slug']

        query_params = {}
        if 'verbose' in params:
            query_params['verbose'] = params['verbose']

        header_params = {}
        if 'sessionkey' in params:
            header_params['sessionkey'] = params['sessionkey']

        form_params = []
        local_var_files = {}

        body_params = None

        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])
        if not header_params['Accept']:
            del header_params['Accept']

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json'])

        # Authentication setting
        auth_settings = []

        return self.api_client.call_api(resource_path, 'DELETE',
                                            path_params,
                                            query_params,
                                            header_params,
                                            body=body_params,
                                            post_params=form_params,
                                            files=local_var_files,
                                            response_type=None,
                                            auth_settings=auth_settings,
                                            callback=params.get('callback'),
                                            _return_http_data_only=params.get('_return_http_data_only'))

    def remove_account(self, slug, account_slug, sessionkey, **kwargs):
        """
        Remove user Account.
        

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.remove_account(slug, account_slug, sessionkey, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str slug: account unique indentifier. (required)
        :param str account_slug: specific account unique indentifier. (required)
        :param str sessionkey: value used to manage user session. (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.remove_account_with_http_info(slug, account_slug, sessionkey, **kwargs)
        else:
            (data) = self.remove_account_with_http_info(slug, account_slug, sessionkey, **kwargs)
            return data

    def remove_account_with_http_info(self, slug, account_slug, sessionkey, **kwargs):
        """
        Remove user Account.
        

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.remove_account_with_http_info(slug, account_slug, sessionkey, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str slug: account unique indentifier. (required)
        :param str account_slug: specific account unique indentifier. (required)
        :param str sessionkey: value used to manage user session. (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['slug', 'account_slug', 'sessionkey']
        all_params.append('callback')
        all_params.append('_return_http_data_only')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method remove_account" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'slug' is set
        if ('slug' not in params) or (params['slug'] is None):
            raise ValueError("Missing the required parameter `slug` when calling `remove_account`")
        # verify the required parameter 'account_slug' is set
        if ('account_slug' not in params) or (params['account_slug'] is None):
            raise ValueError("Missing the required parameter `account_slug` when calling `remove_account`")
        # verify the required parameter 'sessionkey' is set
        if ('sessionkey' not in params) or (params['sessionkey'] is None):
            raise ValueError("Missing the required parameter `sessionkey` when calling `remove_account`")

        resource_path = '/accounts/{slug}/accounts/{account_slug}/'.replace('{format}', 'json')
        path_params = {}
        if 'slug' in params:
            path_params['slug'] = params['slug']
        if 'account_slug' in params:
            path_params['account_slug'] = params['account_slug']

        query_params = {}

        header_params = {}
        if 'sessionkey' in params:
            header_params['sessionkey'] = params['sessionkey']

        form_params = []
        local_var_files = {}

        body_params = None

        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])
        if not header_params['Accept']:
            del header_params['Accept']

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json'])

        # Authentication setting
        auth_settings = []

        return self.api_client.call_api(resource_path, 'DELETE',
                                            path_params,
                                            query_params,
                                            header_params,
                                            body=body_params,
                                            post_params=form_params,
                                            files=local_var_files,
                                            response_type=None,
                                            auth_settings=auth_settings,
                                            callback=params.get('callback'),
                                            _return_http_data_only=params.get('_return_http_data_only'))

    def remove_account_admin(self, slug, admin_slug, sessionkey, **kwargs):
        """
        deletes a admin user from account.
        This can only be done by the logged in user.

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.remove_account_admin(slug, admin_slug, sessionkey, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str slug: account unique indentifier. (required)
        :param str admin_slug: admin account unique indentifier. (required)
        :param str sessionkey: value used to manage user session. (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.remove_account_admin_with_http_info(slug, admin_slug, sessionkey, **kwargs)
        else:
            (data) = self.remove_account_admin_with_http_info(slug, admin_slug, sessionkey, **kwargs)
            return data

    def remove_account_admin_with_http_info(self, slug, admin_slug, sessionkey, **kwargs):
        """
        deletes a admin user from account.
        This can only be done by the logged in user.

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.remove_account_admin_with_http_info(slug, admin_slug, sessionkey, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str slug: account unique indentifier. (required)
        :param str admin_slug: admin account unique indentifier. (required)
        :param str sessionkey: value used to manage user session. (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['slug', 'admin_slug', 'sessionkey']
        all_params.append('callback')
        all_params.append('_return_http_data_only')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method remove_account_admin" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'slug' is set
        if ('slug' not in params) or (params['slug'] is None):
            raise ValueError("Missing the required parameter `slug` when calling `remove_account_admin`")
        # verify the required parameter 'admin_slug' is set
        if ('admin_slug' not in params) or (params['admin_slug'] is None):
            raise ValueError("Missing the required parameter `admin_slug` when calling `remove_account_admin`")
        # verify the required parameter 'sessionkey' is set
        if ('sessionkey' not in params) or (params['sessionkey'] is None):
            raise ValueError("Missing the required parameter `sessionkey` when calling `remove_account_admin`")

        resource_path = '/accounts/{slug}/admins/{admin_slug}/'.replace('{format}', 'json')
        path_params = {}
        if 'slug' in params:
            path_params['slug'] = params['slug']
        if 'admin_slug' in params:
            path_params['admin_slug'] = params['admin_slug']

        query_params = {}

        header_params = {}
        if 'sessionkey' in params:
            header_params['sessionkey'] = params['sessionkey']

        form_params = []
        local_var_files = {}

        body_params = None

        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])
        if not header_params['Accept']:
            del header_params['Accept']

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json'])

        # Authentication setting
        auth_settings = []

        return self.api_client.call_api(resource_path, 'DELETE',
                                            path_params,
                                            query_params,
                                            header_params,
                                            body=body_params,
                                            post_params=form_params,
                                            files=local_var_files,
                                            response_type=None,
                                            auth_settings=auth_settings,
                                            callback=params.get('callback'),
                                            _return_http_data_only=params.get('_return_http_data_only'))

    def remove_account_user(self, slug, user_slug, sessionkey, **kwargs):
        """
        Delete a regular user from account.
        This can only be done by the logged in user.

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.remove_account_user(slug, user_slug, sessionkey, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str slug: account unique indentifier of account from which user needs to be removed. (required)
        :param str user_slug: user account unique indentifier of user which needs to be removed. (required)
        :param str sessionkey: value used to manage user session. (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.remove_account_user_with_http_info(slug, user_slug, sessionkey, **kwargs)
        else:
            (data) = self.remove_account_user_with_http_info(slug, user_slug, sessionkey, **kwargs)
            return data

    def remove_account_user_with_http_info(self, slug, user_slug, sessionkey, **kwargs):
        """
        Delete a regular user from account.
        This can only be done by the logged in user.

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.remove_account_user_with_http_info(slug, user_slug, sessionkey, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str slug: account unique indentifier of account from which user needs to be removed. (required)
        :param str user_slug: user account unique indentifier of user which needs to be removed. (required)
        :param str sessionkey: value used to manage user session. (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['slug', 'user_slug', 'sessionkey']
        all_params.append('callback')
        all_params.append('_return_http_data_only')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method remove_account_user" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'slug' is set
        if ('slug' not in params) or (params['slug'] is None):
            raise ValueError("Missing the required parameter `slug` when calling `remove_account_user`")
        # verify the required parameter 'user_slug' is set
        if ('user_slug' not in params) or (params['user_slug'] is None):
            raise ValueError("Missing the required parameter `user_slug` when calling `remove_account_user`")
        # verify the required parameter 'sessionkey' is set
        if ('sessionkey' not in params) or (params['sessionkey'] is None):
            raise ValueError("Missing the required parameter `sessionkey` when calling `remove_account_user`")

        resource_path = '/accounts/{slug}/users/{user_slug}/'.replace('{format}', 'json')
        path_params = {}
        if 'slug' in params:
            path_params['slug'] = params['slug']
        if 'user_slug' in params:
            path_params['user_slug'] = params['user_slug']

        query_params = {}

        header_params = {}
        if 'sessionkey' in params:
            header_params['sessionkey'] = params['sessionkey']

        form_params = []
        local_var_files = {}

        body_params = None

        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])
        if not header_params['Accept']:
            del header_params['Accept']

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json'])

        # Authentication setting
        auth_settings = []

        return self.api_client.call_api(resource_path, 'DELETE',
                                            path_params,
                                            query_params,
                                            header_params,
                                            body=body_params,
                                            post_params=form_params,
                                            files=local_var_files,
                                            response_type=None,
                                            auth_settings=auth_settings,
                                            callback=params.get('callback'),
                                            _return_http_data_only=params.get('_return_http_data_only'))

    def remove_pending_invited_user(self, slug, sessionkey, body, **kwargs):
        """
        Invite user to join account.
        This can only be done by the logged in user.

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.remove_pending_invited_user(slug, sessionkey, body, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str slug: account unique indentifier. (required)
        :param str sessionkey: user session. (required)
        :param RemovePending body: the content of the request used to add admin into user account. (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.remove_pending_invited_user_with_http_info(slug, sessionkey, body, **kwargs)
        else:
            (data) = self.remove_pending_invited_user_with_http_info(slug, sessionkey, body, **kwargs)
            return data

    def remove_pending_invited_user_with_http_info(self, slug, sessionkey, body, **kwargs):
        """
        Invite user to join account.
        This can only be done by the logged in user.

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.remove_pending_invited_user_with_http_info(slug, sessionkey, body, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str slug: account unique indentifier. (required)
        :param str sessionkey: user session. (required)
        :param RemovePending body: the content of the request used to add admin into user account. (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['slug', 'sessionkey', 'body']
        all_params.append('callback')
        all_params.append('_return_http_data_only')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method remove_pending_invited_user" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'slug' is set
        if ('slug' not in params) or (params['slug'] is None):
            raise ValueError("Missing the required parameter `slug` when calling `remove_pending_invited_user`")
        # verify the required parameter 'sessionkey' is set
        if ('sessionkey' not in params) or (params['sessionkey'] is None):
            raise ValueError("Missing the required parameter `sessionkey` when calling `remove_pending_invited_user`")
        # verify the required parameter 'body' is set
        if ('body' not in params) or (params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `remove_pending_invited_user`")

        resource_path = '/accounts/{slug}/pendings/'.replace('{format}', 'json')
        path_params = {}
        if 'slug' in params:
            path_params['slug'] = params['slug']

        query_params = {}

        header_params = {}
        if 'sessionkey' in params:
            header_params['sessionkey'] = params['sessionkey']

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']

        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])
        if not header_params['Accept']:
            del header_params['Accept']

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json'])

        # Authentication setting
        auth_settings = []

        return self.api_client.call_api(resource_path, 'DELETE',
                                            path_params,
                                            query_params,
                                            header_params,
                                            body=body_params,
                                            post_params=form_params,
                                            files=local_var_files,
                                            response_type=None,
                                            auth_settings=auth_settings,
                                            callback=params.get('callback'),
                                            _return_http_data_only=params.get('_return_http_data_only'))

    def resend_account_verification_email(self, sessionkey, body, **kwargs):
        """
        Resend Email Verification link to verifiy account if already not verified.
        user should be logged in to resend the verification link.

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.resend_account_verification_email(sessionkey, body, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str sessionkey: account session. (required)
        :param ResendAccountVerificationLink body: request data used to resend link to user account. (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.resend_account_verification_email_with_http_info(sessionkey, body, **kwargs)
        else:
            (data) = self.resend_account_verification_email_with_http_info(sessionkey, body, **kwargs)
            return data

    def resend_account_verification_email_with_http_info(self, sessionkey, body, **kwargs):
        """
        Resend Email Verification link to verifiy account if already not verified.
        user should be logged in to resend the verification link.

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.resend_account_verification_email_with_http_info(sessionkey, body, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str sessionkey: account session. (required)
        :param ResendAccountVerificationLink body: request data used to resend link to user account. (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['sessionkey', 'body']
        all_params.append('callback')
        all_params.append('_return_http_data_only')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method resend_account_verification_email" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'sessionkey' is set
        if ('sessionkey' not in params) or (params['sessionkey'] is None):
            raise ValueError("Missing the required parameter `sessionkey` when calling `resend_account_verification_email`")
        # verify the required parameter 'body' is set
        if ('body' not in params) or (params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `resend_account_verification_email`")

        resource_path = '/accounts/resend/emailverification/'.replace('{format}', 'json')
        path_params = {}

        query_params = {}

        header_params = {}
        if 'sessionkey' in params:
            header_params['sessionkey'] = params['sessionkey']

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']

        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])
        if not header_params['Accept']:
            del header_params['Accept']

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json'])

        # Authentication setting
        auth_settings = []

        return self.api_client.call_api(resource_path, 'PUT',
                                            path_params,
                                            query_params,
                                            header_params,
                                            body=body_params,
                                            post_params=form_params,
                                            files=local_var_files,
                                            response_type=None,
                                            auth_settings=auth_settings,
                                            callback=params.get('callback'),
                                            _return_http_data_only=params.get('_return_http_data_only'))

    def reset_password(self, body, **kwargs):
        """
        Reset password of user account.
        

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.reset_password(body, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param ResetPassword body: The request data used to reset user account password. (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.reset_password_with_http_info(body, **kwargs)
        else:
            (data) = self.reset_password_with_http_info(body, **kwargs)
            return data

    def reset_password_with_http_info(self, body, **kwargs):
        """
        Reset password of user account.
        

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.reset_password_with_http_info(body, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param ResetPassword body: The request data used to reset user account password. (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body']
        all_params.append('callback')
        all_params.append('_return_http_data_only')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method reset_password" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if ('body' not in params) or (params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `reset_password`")

        resource_path = '/reset/'.replace('{format}', 'json')
        path_params = {}

        query_params = {}

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']

        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])
        if not header_params['Accept']:
            del header_params['Accept']

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json'])

        # Authentication setting
        auth_settings = []

        return self.api_client.call_api(resource_path, 'POST',
                                            path_params,
                                            query_params,
                                            header_params,
                                            body=body_params,
                                            post_params=form_params,
                                            files=local_var_files,
                                            response_type=None,
                                            auth_settings=auth_settings,
                                            callback=params.get('callback'),
                                            _return_http_data_only=params.get('_return_http_data_only'))

    def search_accounts(self, sessionkey, pattern, **kwargs):
        """
        Search accounts by starting keywords of account name .
        user should be logged in to search accounts.

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.search_accounts(sessionkey, pattern, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str sessionkey: account session. (required)
        :param str pattern: parameter to provide search accounts with passed starting keywords. (required)
        :param int account: Needs to send 1 if you want matching accounts list. Default will be 0.
        :param int organization: organization=1 for organization only, organization=0 for ~organization. Default will include all
        :return: Users
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.search_accounts_with_http_info(sessionkey, pattern, **kwargs)
        else:
            (data) = self.search_accounts_with_http_info(sessionkey, pattern, **kwargs)
            return data

    def search_accounts_with_http_info(self, sessionkey, pattern, **kwargs):
        """
        Search accounts by starting keywords of account name .
        user should be logged in to search accounts.

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.search_accounts_with_http_info(sessionkey, pattern, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str sessionkey: account session. (required)
        :param str pattern: parameter to provide search accounts with passed starting keywords. (required)
        :param int account: Needs to send 1 if you want matching accounts list. Default will be 0.
        :param int organization: organization=1 for organization only, organization=0 for ~organization. Default will include all
        :return: Users
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['sessionkey', 'pattern', 'account', 'organization']
        all_params.append('callback')
        all_params.append('_return_http_data_only')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method search_accounts" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'sessionkey' is set
        if ('sessionkey' not in params) or (params['sessionkey'] is None):
            raise ValueError("Missing the required parameter `sessionkey` when calling `search_accounts`")
        # verify the required parameter 'pattern' is set
        if ('pattern' not in params) or (params['pattern'] is None):
            raise ValueError("Missing the required parameter `pattern` when calling `search_accounts`")

        resource_path = '/accounts/search/{pattern}/'.replace('{format}', 'json')
        path_params = {}
        if 'pattern' in params:
            path_params['pattern'] = params['pattern']

        query_params = {}
        if 'account' in params:
            query_params['account'] = params['account']
        if 'organization' in params:
            query_params['organization'] = params['organization']

        header_params = {}
        if 'sessionkey' in params:
            header_params['sessionkey'] = params['sessionkey']

        form_params = []
        local_var_files = {}

        body_params = None

        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])
        if not header_params['Accept']:
            del header_params['Accept']

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json'])

        # Authentication setting
        auth_settings = []

        return self.api_client.call_api(resource_path, 'GET',
                                            path_params,
                                            query_params,
                                            header_params,
                                            body=body_params,
                                            post_params=form_params,
                                            files=local_var_files,
                                            response_type='Users',
                                            auth_settings=auth_settings,
                                            callback=params.get('callback'),
                                            _return_http_data_only=params.get('_return_http_data_only'))

    def set_current_account(self, slug, sessionkey, body, **kwargs):
        """
        Set user current account.
        

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.set_current_account(slug, sessionkey, body, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str slug: unique value which will be used to fetch user account details. (required)
        :param str sessionkey: value used to manage user session. (required)
        :param ChangeCurrentAccount body: request data used to change current account. (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.set_current_account_with_http_info(slug, sessionkey, body, **kwargs)
        else:
            (data) = self.set_current_account_with_http_info(slug, sessionkey, body, **kwargs)
            return data

    def set_current_account_with_http_info(self, slug, sessionkey, body, **kwargs):
        """
        Set user current account.
        

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.set_current_account_with_http_info(slug, sessionkey, body, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str slug: unique value which will be used to fetch user account details. (required)
        :param str sessionkey: value used to manage user session. (required)
        :param ChangeCurrentAccount body: request data used to change current account. (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['slug', 'sessionkey', 'body']
        all_params.append('callback')
        all_params.append('_return_http_data_only')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method set_current_account" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'slug' is set
        if ('slug' not in params) or (params['slug'] is None):
            raise ValueError("Missing the required parameter `slug` when calling `set_current_account`")
        # verify the required parameter 'sessionkey' is set
        if ('sessionkey' not in params) or (params['sessionkey'] is None):
            raise ValueError("Missing the required parameter `sessionkey` when calling `set_current_account`")
        # verify the required parameter 'body' is set
        if ('body' not in params) or (params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `set_current_account`")

        resource_path = '/accounts/{slug}/current/'.replace('{format}', 'json')
        path_params = {}
        if 'slug' in params:
            path_params['slug'] = params['slug']

        query_params = {}

        header_params = {}
        if 'sessionkey' in params:
            header_params['sessionkey'] = params['sessionkey']

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']

        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])
        if not header_params['Accept']:
            del header_params['Accept']

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json'])

        # Authentication setting
        auth_settings = []

        return self.api_client.call_api(resource_path, 'PUT',
                                            path_params,
                                            query_params,
                                            header_params,
                                            body=body_params,
                                            post_params=form_params,
                                            files=local_var_files,
                                            response_type=None,
                                            auth_settings=auth_settings,
                                            callback=params.get('callback'),
                                            _return_http_data_only=params.get('_return_http_data_only'))

    def update_account(self, slug, body, **kwargs):
        """
        Update User Account.
        

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.update_account(slug, body, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str slug: unique value which will be used to fetch user account details. (required)
        :param UpdateAccount body: request data used to update user account. (required)
        :param str sessionkey: user session.
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.update_account_with_http_info(slug, body, **kwargs)
        else:
            (data) = self.update_account_with_http_info(slug, body, **kwargs)
            return data

    def update_account_with_http_info(self, slug, body, **kwargs):
        """
        Update User Account.
        

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.update_account_with_http_info(slug, body, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str slug: unique value which will be used to fetch user account details. (required)
        :param UpdateAccount body: request data used to update user account. (required)
        :param str sessionkey: user session.
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['slug', 'body', 'sessionkey']
        all_params.append('callback')
        all_params.append('_return_http_data_only')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method update_account" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'slug' is set
        if ('slug' not in params) or (params['slug'] is None):
            raise ValueError("Missing the required parameter `slug` when calling `update_account`")
        # verify the required parameter 'body' is set
        if ('body' not in params) or (params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `update_account`")

        resource_path = '/accounts/{slug}/'.replace('{format}', 'json')
        path_params = {}
        if 'slug' in params:
            path_params['slug'] = params['slug']

        query_params = {}

        header_params = {}
        if 'sessionkey' in params:
            header_params['sessionkey'] = params['sessionkey']

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']

        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])
        if not header_params['Accept']:
            del header_params['Accept']

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json'])

        # Authentication setting
        auth_settings = []

        return self.api_client.call_api(resource_path, 'PUT',
                                            path_params,
                                            query_params,
                                            header_params,
                                            body=body_params,
                                            post_params=form_params,
                                            files=local_var_files,
                                            response_type=None,
                                            auth_settings=auth_settings,
                                            callback=params.get('callback'),
                                            _return_http_data_only=params.get('_return_http_data_only'))



# coding: utf-8

"""
    Swagger Blended Hub API Explorer

    A collection of Swagger documentation for the Blended Hub APIs.

    OpenAPI spec version: 1.0.0
    Contact: api@blended.co
    Generated by: https://github.com/swagger-api/swagger-codegen.git

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.
"""

from pprint import pformat
from six import iteritems
import re


class BundledPackagesError(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self, label=None, package=None, license_name=None, license_type=None, price=None, title=None, type=None, third_party=None, dependency_of_package=None, license_type_dependency_of_package=None, thumbnail_image=None, error=None):
        """
        BundledPackagesError - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'label': 'str',
            'package': 'str',
            'license_name': 'str',
            'license_type': 'str',
            'price': 'float',
            'title': 'str',
            'type': 'str',
            'third_party': 'str',
            'dependency_of_package': 'str',
            'license_type_dependency_of_package': 'str',
            'thumbnail_image': 'str',
            'error': 'list[PublicationValidationError]'
        }

        self.attribute_map = {
            'label': 'label',
            'package': 'package',
            'license_name': 'license_name',
            'license_type': 'license_type',
            'price': 'price',
            'title': 'title',
            'type': 'type',
            'third_party': 'third_party',
            'dependency_of_package': 'dependency_of_package',
            'license_type_dependency_of_package': 'license_type_dependency_of_package',
            'thumbnail_image': 'thumbnail_image',
            'error': 'ERROR'
        }

        self._label = label
        self._package = package
        self._license_name = license_name
        self._license_type = license_type
        self._price = price
        self._title = title
        self._type = type
        self._third_party = third_party
        self._dependency_of_package = dependency_of_package
        self._license_type_dependency_of_package = license_type_dependency_of_package
        self._thumbnail_image = thumbnail_image
        self._error = error

    @property
    def label(self):
        """
        Gets the label of this BundledPackagesError.
        label of package version

        :return: The label of this BundledPackagesError.
        :rtype: str
        """
        return self._label

    @label.setter
    def label(self, label):
        """
        Sets the label of this BundledPackagesError.
        label of package version

        :param label: The label of this BundledPackagesError.
        :type: str
        """

        self._label = label

    @property
    def package(self):
        """
        Gets the package of this BundledPackagesError.
        fully qualified name of package

        :return: The package of this BundledPackagesError.
        :rtype: str
        """
        return self._package

    @package.setter
    def package(self, package):
        """
        Sets the package of this BundledPackagesError.
        fully qualified name of package

        :param package: The package of this BundledPackagesError.
        :type: str
        """

        self._package = package

    @property
    def license_name(self):
        """
        Gets the license_name of this BundledPackagesError.
        license name

        :return: The license_name of this BundledPackagesError.
        :rtype: str
        """
        return self._license_name

    @license_name.setter
    def license_name(self, license_name):
        """
        Sets the license_name of this BundledPackagesError.
        license name

        :param license_name: The license_name of this BundledPackagesError.
        :type: str
        """

        self._license_name = license_name

    @property
    def license_type(self):
        """
        Gets the license_type of this BundledPackagesError.
        license type

        :return: The license_type of this BundledPackagesError.
        :rtype: str
        """
        return self._license_type

    @license_type.setter
    def license_type(self, license_type):
        """
        Sets the license_type of this BundledPackagesError.
        license type

        :param license_type: The license_type of this BundledPackagesError.
        :type: str
        """

        self._license_type = license_type

    @property
    def price(self):
        """
        Gets the price of this BundledPackagesError.
        license type

        :return: The price of this BundledPackagesError.
        :rtype: float
        """
        return self._price

    @price.setter
    def price(self, price):
        """
        Sets the price of this BundledPackagesError.
        license type

        :param price: The price of this BundledPackagesError.
        :type: float
        """

        self._price = price

    @property
    def title(self):
        """
        Gets the title of this BundledPackagesError.
        title of bundled package

        :return: The title of this BundledPackagesError.
        :rtype: str
        """
        return self._title

    @title.setter
    def title(self, title):
        """
        Sets the title of this BundledPackagesError.
        title of bundled package

        :param title: The title of this BundledPackagesError.
        :type: str
        """

        self._title = title

    @property
    def type(self):
        """
        Gets the type of this BundledPackagesError.
        type of bundled package

        :return: The type of this BundledPackagesError.
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """
        Sets the type of this BundledPackagesError.
        type of bundled package

        :param type: The type of this BundledPackagesError.
        :type: str
        """

        self._type = type

    @property
    def third_party(self):
        """
        Gets the third_party of this BundledPackagesError.
        is it a third_party package?

        :return: The third_party of this BundledPackagesError.
        :rtype: str
        """
        return self._third_party

    @third_party.setter
    def third_party(self, third_party):
        """
        Sets the third_party of this BundledPackagesError.
        is it a third_party package?

        :param third_party: The third_party of this BundledPackagesError.
        :type: str
        """

        self._third_party = third_party

    @property
    def dependency_of_package(self):
        """
        Gets the dependency_of_package of this BundledPackagesError.
        package name of upstream package

        :return: The dependency_of_package of this BundledPackagesError.
        :rtype: str
        """
        return self._dependency_of_package

    @dependency_of_package.setter
    def dependency_of_package(self, dependency_of_package):
        """
        Sets the dependency_of_package of this BundledPackagesError.
        package name of upstream package

        :param dependency_of_package: The dependency_of_package of this BundledPackagesError.
        :type: str
        """

        self._dependency_of_package = dependency_of_package

    @property
    def license_type_dependency_of_package(self):
        """
        Gets the license_type_dependency_of_package of this BundledPackagesError.
        license_type of upstream package

        :return: The license_type_dependency_of_package of this BundledPackagesError.
        :rtype: str
        """
        return self._license_type_dependency_of_package

    @license_type_dependency_of_package.setter
    def license_type_dependency_of_package(self, license_type_dependency_of_package):
        """
        Sets the license_type_dependency_of_package of this BundledPackagesError.
        license_type of upstream package

        :param license_type_dependency_of_package: The license_type_dependency_of_package of this BundledPackagesError.
        :type: str
        """

        self._license_type_dependency_of_package = license_type_dependency_of_package

    @property
    def thumbnail_image(self):
        """
        Gets the thumbnail_image of this BundledPackagesError.
        thumbnail_image of upstream package

        :return: The thumbnail_image of this BundledPackagesError.
        :rtype: str
        """
        return self._thumbnail_image

    @thumbnail_image.setter
    def thumbnail_image(self, thumbnail_image):
        """
        Sets the thumbnail_image of this BundledPackagesError.
        thumbnail_image of upstream package

        :param thumbnail_image: The thumbnail_image of this BundledPackagesError.
        :type: str
        """

        self._thumbnail_image = thumbnail_image

    @property
    def error(self):
        """
        Gets the error of this BundledPackagesError.
        list of errors will be displayed here.

        :return: The error of this BundledPackagesError.
        :rtype: list[PublicationValidationError]
        """
        return self._error

    @error.setter
    def error(self, error):
        """
        Sets the error of this BundledPackagesError.
        list of errors will be displayed here.

        :param error: The error of this BundledPackagesError.
        :type: list[PublicationValidationError]
        """

        self._error = error

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other
